@@ -154,14 +154,16 @@ public class FormatData_de extends ListResourceBundle {
                "Q3",
                "Q4",
             };
-        final String[] metaValue_narrow_AmPmMarkers = new String[] {
-               "a",
-               "p",
-            };
         final String[] metaValue_long_Eras = new String[] {
                "v. Chr.",
                "n. Chr.",
             };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
@@ -176,6 +178,10 @@ public class FormatData_de extends ListResourceBundle {
                "BC",
                "B.E.",
             };
+        final String[] metaValue_java_time_buddhist_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d. MMMM y G",
                "d. MMMM y G",
@@ -200,18 +206,23 @@ public class FormatData_de extends ListResourceBundle {
                "v. VR China",
                "Minguo",
             };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "Gregorianischer Kalender";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "Jahr" },
             { "calendarname.islamic-umalqura", "Islamischer Kalender (Umm al-Qura" },
             { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "B\u00fcrgerlicher islamischer Kalender" },
-            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_long_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "timezone.regionFormat.standard", "{0} Normalzeit" },
@@ -229,7 +240,9 @@ public class FormatData_de extends ListResourceBundle {
                 }
             },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -241,7 +254,6 @@ public class FormatData_de extends ListResourceBundle {
                     "{1}, {0}",
                 }
             },
-            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -255,6 +267,8 @@ public class FormatData_de extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -281,26 +295,21 @@ public class FormatData_de extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "Kalender der Republik China" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "Monat" },
             { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "Sekunde" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Islamischer Kalender" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
                 new String[] {
                     "Jan",
@@ -324,21 +333,20 @@ public class FormatData_de extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 Tausend",
-                    "00 Tausend",
-                    "000 Tausend",
-                    "0 Million",
-                    "00 Millionen",
-                    "000 Millionen",
-                    "0 Milliarde",
-                    "00 Milliarden",
-                    "000 Milliarden",
-                    "0 Billion",
-                    "00 Billionen",
-                    "000 Billionen",
+                    "{one:0' 'Tausend other:0' 'Tausend}",
+                    "{one:00' 'Tausend other:00' 'Tausend}",
+                    "{one:000' 'Tausend other:000' 'Tausend}",
+                    "{one:0' 'Million other:0' 'Millionen}",
+                    "{one:00' 'Millionen other:00' 'Millionen}",
+                    "{one:000' 'Millionen other:000' 'Millionen}",
+                    "{one:0' 'Milliarde other:0' 'Milliarden}",
+                    "{one:00' 'Milliarden other:00' 'Milliarden}",
+                    "{one:000' 'Milliarden other:000' 'Milliarden}",
+                    "{one:0' 'Billion other:0' 'Billionen}",
+                    "{one:00' 'Billionen other:00' 'Billionen}",
+                    "{one:000' 'Billionen other:000' 'Billionen}",
                 }
             },
-            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
@@ -348,12 +356,13 @@ public class FormatData_de extends ListResourceBundle {
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "Zeitzone" },
             { "japanese.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
-            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "Eras", metaValue_long_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
@@ -361,18 +370,23 @@ public class FormatData_de extends ListResourceBundle {
             { "field.weekday", "Wochentag" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "field.week", "Woche" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -380,21 +394,22 @@ public class FormatData_de extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0",
-                    "0",
-                    "0",
-                    "0\u00a0Mio'.'",
-                    "00\u00a0Mio'.'",
-                    "000\u00a0Mio'.'",
-                    "0\u00a0Mrd'.'",
-                    "00\u00a0Mrd'.'",
-                    "000\u00a0Mrd'.'",
-                    "0\u00a0Bio'.'",
-                    "00\u00a0Bio'.'",
-                    "000\u00a0Bio'.'",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0 other:0}",
+                    "{one:0\u00a0Mio'.' other:0\u00a0Mio'.'}",
+                    "{one:00\u00a0Mio'.' other:00\u00a0Mio'.'}",
+                    "{one:000\u00a0Mio'.' other:000\u00a0Mio'.'}",
+                    "{one:0\u00a0Mrd'.' other:0\u00a0Mrd'.'}",
+                    "{one:00\u00a0Mrd'.' other:00\u00a0Mrd'.'}",
+                    "{one:000\u00a0Mrd'.' other:000\u00a0Mrd'.'}",
+                    "{one:0\u00a0Bio'.' other:0\u00a0Bio'.'}",
+                    "{one:00\u00a0Bio'.' other:00\u00a0Bio'.'}",
+                    "{one:000\u00a0Bio'.' other:000\u00a0Bio'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
             { "timezone.regionFormat.daylight", "{0} Sommerzeit" },
             { "DatePatterns",
                 new String[] {
@@ -405,14 +420,26 @@ public class FormatData_de extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "Stunde" },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "Buddhistischer Kalender" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
