@@ -170,6 +170,10 @@ public class FormatData_in extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, dd MMMM y G",
                "d MMMM y G",
@@ -182,13 +186,9 @@ public class FormatData_in extends ListResourceBundle {
                "d MMM y GGGG",
                "d/M/y G",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "Sebelum R.O.C.",
-               "",
+               "R.O.C.",
             };
         final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
@@ -199,12 +199,13 @@ public class FormatData_in extends ListResourceBundle {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "tahun" },
             { "calendarname.islamic-umalqura", "Kalender Islam (Umm al-Qura)" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "Kalender Sipil Islam" },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -220,6 +221,7 @@ public class FormatData_in extends ListResourceBundle {
                     "Masehi",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -244,6 +246,8 @@ public class FormatData_in extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -251,26 +255,28 @@ public class FormatData_in extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "menit" },
             { "field.era", "era" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.MonthNames",
                 new String[] {
-                    "Muharram",
+                    "Muharam",
                     "Safar",
-                    "Rabi\u02bb I",
-                    "Rabi\u02bb II",
-                    "Jumada I",
-                    "Jumada II",
+                    "Rabiulawal",
+                    "Rabiulakhir",
+                    "Jumadilawal",
+                    "Jumadilakhir",
                     "Rajab",
-                    "Sya\u2019ban",
-                    "Ramadhan",
+                    "Syakban",
+                    "Ramadan",
                     "Syawal",
-                    "Dhu\u02bbl-Qi\u02bbdah",
-                    "Dhu\u02bbl-Hijjah",
+                    "Zulkaidah",
+                    "Zulhijah",
                     "",
                 }
             },
-            { "calendarname.roc", "Kalendar Minguo" },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "calendarname.roc", "Kalender Min-guo" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
@@ -279,18 +285,11 @@ public class FormatData_in extends ListResourceBundle {
             { "field.second", "detik" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Kalender Islam" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Waktu {0}" },
@@ -299,34 +298,35 @@ public class FormatData_in extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 ribu",
-                    "00 ribu",
-                    "000 ribu",
-                    "0 juta",
-                    "00 juta",
-                    "000 juta",
-                    "0 miliar",
-                    "00 miliar",
-                    "000 miliar",
-                    "0 triliun",
-                    "00 triliun",
-                    "000 triliun",
+                    "{other:0' 'ribu}",
+                    "{other:00' 'ribu}",
+                    "{other:000' 'ribu}",
+                    "{other:0' 'juta}",
+                    "{other:00' 'juta}",
+                    "{other:000' 'juta}",
+                    "{other:0' 'miliar}",
+                    "{other:00' 'miliar}",
+                    "{other:000' 'miliar}",
+                    "{other:0' 'triliun}",
+                    "{other:00' 'triliun}",
+                    "{other:000' 'triliun}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "zona waktu" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
@@ -365,7 +365,7 @@ public class FormatData_in extends ListResourceBundle {
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -373,18 +373,18 @@ public class FormatData_in extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0rb",
-                    "00\u00a0rb",
-                    "000\u00a0rb",
-                    "0\u00a0jt",
-                    "00\u00a0jt",
-                    "000\u00a0jt",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0\u00a0T",
-                    "00\u00a0T",
-                    "000\u00a0T",
+                    "{other:0\u00a0rb}",
+                    "{other:00\u00a0rb}",
+                    "{other:000\u00a0rb}",
+                    "{other:0\u00a0jt}",
+                    "{other:00\u00a0jt}",
+                    "{other:000\u00a0jt}",
+                    "{other:0\u00a0M}",
+                    "{other:00\u00a0M}",
+                    "{other:000\u00a0M}",
+                    "{other:0\u00a0T}",
+                    "{other:00\u00a0T}",
+                    "{other:000\u00a0T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -406,22 +406,30 @@ public class FormatData_in extends ListResourceBundle {
                 new String[] {
                     "Muh.",
                     "Saf.",
-                    "Rab. I",
-                    "Rab. II",
-                    "Jum. I",
-                    "Jum. II",
+                    "Rab. Awal",
+                    "Rab. Akhir",
+                    "Jum. Awal",
+                    "Jum. Akhir",
                     "Raj.",
-                    "Sha.",
+                    "Sya.",
                     "Ram.",
                     "Syaw.",
-                    "Dhu\u02bbl-Q.",
-                    "Dhu\u02bbl-H.",
+                    "Zulka.",
+                    "Zulhi.",
                     "",
                 }
             },
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "Kalender Buddha" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
