@@ -174,6 +174,10 @@ public class FormatData_ka extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, dd MMMM, y G",
                "d MMMM, y G",
@@ -186,49 +190,33 @@ public class FormatData_ka extends ListResourceBundle {
                "d MMM, y GGGG",
                "dd.MM.y G",
             };
-        final String[] metaValue_roc_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String metaValue_calendarname_gregorian = "\u10d2\u10e0\u10d8\u10d2\u10dd\u10e0\u10d8\u10d0\u10dc\u10e3\u10da\u10d8 \u10d9\u10d0\u10da\u10d4\u10dc\u10d3\u10d0\u10e0\u10d8";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u10ec\u10d4\u10da\u10d8" },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
-            { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
-            { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "field.zone", "\u10d3\u10e0\u10dd\u10d8\u10e1 \u10e1\u10d0\u10e0\u10e2\u10e7\u10d4\u10da\u10d8" },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\u10d8\u10e1\u10da\u10d0\u10db\u10e3\u10e0\u10d8 \u10e1\u10d0\u10db\u10dd\u10e5\u10d0\u10da\u10d0\u10e5\u10dd \u10d9\u10d0\u10da\u10d4\u10dc\u10d3\u10d0\u10e0\u10d8" },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "timezone.regionFormat.standard", "{0} \u10e1\u10e2\u10d0\u10dc\u10d3\u10d0\u10e0\u10e2\u10e3\u10da\u10d8 \u10d3\u10e0\u10dd" },
             { "calendarname.japanese", "\u10d8\u10d0\u10de\u10dd\u10dc\u10e3\u10e0\u10d8 \u10d9\u10d0\u10da\u10d4\u10dc\u10d3\u10d0\u10e0\u10d8" },
-            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "Eras", metaValue_Eras },
             { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.DayNames", metaValue_DayNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.QuarterNames", metaValue_QuarterNames },
             { "long.Eras",
                 new String[] {
                     "\u10eb\u10d5\u10d4\u10da\u10d8 \u10ec\u10d4\u10da\u10d7\u10d0\u10e6\u10e0\u10d8\u10ea\u10ee\u10d5\u10d8\u10d7",
                     "\u10d0\u10ee\u10d0\u10da\u10d8 \u10ec\u10d4\u10da\u10d7\u10d0\u10e6\u10e0\u10d8\u10ea\u10ee\u10d5\u10d8\u10d7",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "field.weekday", "\u10d9\u10d5\u10d8\u10e0\u10d8\u10e1 \u10d3\u10e6\u10d4" },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "DateTimePatterns",
                 new String[] {
@@ -252,46 +240,84 @@ public class FormatData_ka extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u10d0\u10e0\u00a0\u10d0\u10e0\u10d8\u10e1\u00a0\u10e0\u10d8\u10ea\u10ee\u10d5\u10d8",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u10ec\u10e3\u10d7\u10d8" },
             { "field.era", "\u10d4\u10de\u10dd\u10e5\u10d0" },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "\u10d3\u10e6\u10d8\u10e1 \u10dc\u10d0\u10ee\u10d4\u10d5\u10d0\u10e0\u10d8" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u10e9\u10d8\u10dc\u10d4\u10d7\u10d8\u10e1 \u10e0\u10d4\u10e1\u10de\u10e3\u10d1\u10da\u10d8\u10d9\u10d8\u10e1 \u10d9\u10d0\u10da\u10d4\u10dc\u10d3\u10d0\u10e0\u10d8" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "field.month", "\u10d7\u10d5\u10d4" },
+            { "field.second", "\u10ec\u10d0\u10db\u10d8" },
+            { "DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNarrows", metaValue_DayNarrows },
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "calendarname.islamic", "\u10d8\u10e1\u10da\u10d0\u10db\u10e3\u10e0\u10d8 \u10d9\u10d0\u10da\u10d4\u10dc\u10d3\u10d0\u10e0\u10d8" },
+            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
+            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "timezone.regionFormat", "\u10d3\u10e0\u10dd: {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{one:0' '\u10d0\u10d7\u10d0\u10e1\u10d8 other:0' '\u10d0\u10d7\u10d0\u10e1\u10d8}",
+                    "{one:00' '\u10d0\u10d7\u10d0\u10e1\u10d8 other:00' '\u10d0\u10d7\u10d0\u10e1\u10d8}",
+                    "{one:000' '\u10d0\u10d7\u10d0\u10e1\u10d8 other:000' '\u10d0\u10d7\u10d0\u10e1\u10d8}",
+                    "{one:0' '\u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8 other:0' '\u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8}",
+                    "{one:00' '\u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8 other:00' '\u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8}",
+                    "{one:000' '\u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8 other:000' '\u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8}",
+                    "{one:0' '\u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8 other:0' '\u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8}",
+                    "{one:00' '\u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8 other:00' '\u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8}",
+                    "{one:000' '\u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8 other:000' '\u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8}",
+                    "{one:0' '\u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8 other:0' '\u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8}",
+                    "{one:00' '\u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8 other:00' '\u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8}",
+                    "{one:000' '\u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8 other:000' '\u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8}",
+                }
+            },
+            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "standalone.QuarterNames", metaValue_QuarterNames },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "TimePatterns", metaValue_TimePatterns },
+            { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "field.zone", "\u10d3\u10e0\u10dd\u10d8\u10e1 \u10e1\u10d0\u10e0\u10e2\u10e7\u10d4\u10da\u10d8" },
+            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "Eras", metaValue_Eras },
+            { "roc.DayNames", metaValue_DayNames },
+            { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "field.weekday", "\u10d9\u10d5\u10d8\u10e0\u10d8\u10e1 \u10d3\u10e6\u10d4" },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "japanese.QuarterNames", metaValue_QuarterNames },
+            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
-            { "field.month", "\u10d7\u10d5\u10d4" },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "field.second", "\u10ec\u10d0\u10db\u10d8" },
             { "roc.MonthNames", metaValue_MonthNames },
             { "field.week", "\u10d9\u10d5\u10d8\u10e0\u10d0" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "calendarname.islamic", "\u10d8\u10e1\u10da\u10d0\u10db\u10e3\u10e0\u10d8 \u10d9\u10d0\u10da\u10d4\u10dc\u10d3\u10d0\u10e0\u10d8" },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -299,18 +325,18 @@ public class FormatData_ka extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u10d0\u10d7'.'",
-                    "00\u00a0\u10d0\u10d7'.'",
-                    "000\u00a0\u10d0\u10d7'.'",
-                    "0\u00a0\u10db\u10da\u10dc'.'",
-                    "00\u00a0\u10db\u10da\u10dc'.'",
-                    "000\u00a0\u10db\u10da\u10dc'.'",
-                    "0\u00a0\u10db\u10da\u10e0\u10d3'.'",
-                    "00\u00a0\u10db\u10da\u10e0\u10d3'.'",
-                    "000\u00a0\u10db\u10da\u10e0'.'",
-                    "0\u00a0\u10e2\u10e0\u10da'.'",
-                    "00\u00a0\u10e2\u10e0\u10da'.'",
-                    "000\u00a0\u10e2\u10e0\u10da'.'",
+                    "{one:0\u00a0\u10d0\u10d7'.' other:0\u00a0\u10d0\u10d7'.'}",
+                    "{one:00\u00a0\u10d0\u10d7'.' other:00\u00a0\u10d0\u10d7'.'}",
+                    "{one:000\u00a0\u10d0\u10d7'.' other:000\u00a0\u10d0\u10d7'.'}",
+                    "{one:0\u00a0\u10db\u10da\u10dc'.' other:0\u00a0\u10db\u10da\u10dc'.'}",
+                    "{one:00\u00a0\u10db\u10da\u10dc'.' other:00\u00a0\u10db\u10da\u10dc'.'}",
+                    "{one:000\u00a0\u10db\u10da\u10dc'.' other:000\u00a0\u10db\u10da\u10dc'.'}",
+                    "{one:0\u00a0\u10db\u10da\u10e0\u10d3'.' other:0\u00a0\u10db\u10da\u10e0\u10d3'.'}",
+                    "{one:00\u00a0\u10db\u10da\u10e0\u10d3'.' other:00\u00a0\u10db\u10da\u10e0\u10d3'.'}",
+                    "{one:000\u00a0\u10db\u10da\u10e0'.' other:000\u00a0\u10db\u10da\u10e0'.'}",
+                    "{one:0\u00a0\u10e2\u10e0\u10da'.' other:0\u00a0\u10e2\u10e0\u10da'.'}",
+                    "{one:00\u00a0\u10e2\u10e0\u10da'.' other:00\u00a0\u10e2\u10e0\u10da'.'}",
+                    "{one:000\u00a0\u10e2\u10e0\u10da'.' other:000\u00a0\u10e2\u10e0\u10da'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -328,40 +354,21 @@ public class FormatData_ka extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u10e1\u10d0\u10d0\u10d7\u10d8" },
-            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "calendarname.buddhist", "\u10d1\u10e3\u10d3\u10d8\u10e1\u10e2\u10e3\u10e0\u10d8 \u10d9\u10d0\u10da\u10d4\u10dc\u10d3\u10d0\u10e0\u10d8" },
             { "standalone.MonthNames", metaValue_MonthNames },
-            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "timezone.regionFormat", "\u10d3\u10e0\u10dd: {0}" },
-            { "long.CompactNumberPatterns",
+            { "latn.NumberPatterns",
                 new String[] {
-                    "",
-                    "",
-                    "",
-                    "0 \u10d0\u10d7\u10d0\u10e1\u10d8",
-                    "00 \u10d0\u10d7\u10d0\u10e1\u10d8",
-                    "000 \u10d0\u10d7\u10d0\u10e1\u10d8",
-                    "0 \u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
-                    "00 \u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
-                    "000 \u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
-                    "0 \u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8",
-                    "00 \u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8",
-                    "000 \u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8",
-                    "0 \u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
-                    "00 \u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
-                    "000 \u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
                 }
             },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
