@@ -222,6 +222,7 @@ public class FormatData_ky extends ListResourceBundle {
                     "\u0431\u0438\u0437\u0434\u0438\u043d \u0437\u0430\u043c\u0430\u043d",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -247,6 +248,8 @@ public class FormatData_ky extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u0441\u0430\u043d\u00a0\u044d\u043c\u0435\u0441",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -257,6 +260,7 @@ public class FormatData_ky extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u0422\u0427/\u0422\u041a" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u041c\u0438\u043d\u0433\u0443\u043e \u0436\u044b\u043b\u043d\u0430\u0430\u043c\u0430\u0441\u044b" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -264,13 +268,6 @@ public class FormatData_ky extends ListResourceBundle {
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0418\u0441\u043b\u0430\u043c \u0436\u044b\u043b\u043d\u0430\u0430\u043c\u0430\u0441\u044b" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -298,18 +295,18 @@ public class FormatData_ky extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u043c\u0438\u04a3",
-                    "00 \u043c\u0438\u04a3",
-                    "000 \u043c\u0438\u04a3",
-                    "0 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "00 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "000 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "0 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "00 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "000 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "0 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "00 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "000 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "{one:0' '\u043c\u0438\u04a3 other:0' '\u043c\u0438\u04a3}",
+                    "{one:00' '\u043c\u0438\u04a3 other:00' '\u043c\u0438\u04a3}",
+                    "{one:000' '\u043c\u0438\u04a3 other:000' '\u043c\u0438\u04a3}",
+                    "{one:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{one:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{one:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{one:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d other:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d other:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d other:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -354,18 +351,18 @@ public class FormatData_ky extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u043c\u0438\u04a3",
-                    "00\u00a0\u043c\u0438\u04a3",
-                    "000\u00a0\u043c\u0438\u04a3",
-                    "0\u00a0\u043c\u043b\u043d",
-                    "00\u00a0\u043c\u043b\u043d",
-                    "000\u00a0\u043c\u043b\u043d",
-                    "0\u00a0\u043c\u043b\u0434",
-                    "00\u00a0\u043c\u043b\u0434",
-                    "000\u00a0\u043c\u043b\u0434",
-                    "0\u00a0\u0442\u0440\u043b\u043d",
-                    "00\u00a0\u0442\u0440\u043b\u043d",
-                    "000\u00a0\u0442\u0440\u043b\u043d",
+                    "{one:0\u00a0\u043c\u0438\u04a3 other:0\u00a0\u043c\u0438\u04a3}",
+                    "{one:00\u00a0\u043c\u0438\u04a3 other:00\u00a0\u043c\u0438\u04a3}",
+                    "{one:000\u00a0\u043c\u0438\u04a3 other:000\u00a0\u043c\u0438\u04a3}",
+                    "{one:0\u00a0\u043c\u043b\u043d other:0\u00a0\u043c\u043b\u043d}",
+                    "{one:00\u00a0\u043c\u043b\u043d other:00\u00a0\u043c\u043b\u043d}",
+                    "{one:000\u00a0\u043c\u043b\u043d other:000\u00a0\u043c\u043b\u043d}",
+                    "{one:0\u00a0\u043c\u043b\u0434 other:0\u00a0\u043c\u043b\u0434}",
+                    "{one:00\u00a0\u043c\u043b\u0434 other:00\u00a0\u043c\u043b\u0434}",
+                    "{one:000\u00a0\u043c\u043b\u0434 other:000\u00a0\u043c\u043b\u0434}",
+                    "{one:0\u00a0\u0442\u0440\u043b\u043d other:0\u00a0\u0442\u0440\u043b\u043d}",
+                    "{one:00\u00a0\u0442\u0440\u043b\u043d other:00\u00a0\u0442\u0440\u043b\u043d}",
+                    "{one:000\u00a0\u0442\u0440\u043b\u043d other:000\u00a0\u0442\u0440\u043b\u043d}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -400,6 +397,14 @@ public class FormatData_ky extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
