@@ -164,6 +164,14 @@ public class FormatData_ml extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "G y, MMMM d, EEEE",
                "G y, MMMM d",
@@ -176,10 +184,6 @@ public class FormatData_ml extends ListResourceBundle {
                "GGGG y, MMM d",
                "G y-MM-dd",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "R.O.C-\u0d2f\u0d4d\u200c\u0d15\u0d4d\u0d15\u0d4d \u0d2e\u0d41\u0d2e\u0d4d\u0d2a\u0d4d",
                "\u0d2e\u0d3f\u0d02\u0d17\u0d4d\u0d35\u0d4b",
@@ -197,13 +201,15 @@ public class FormatData_ml extends ListResourceBundle {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0d35\u0d7c\u0d37\u0d02" },
             { "calendarname.islamic-umalqura", "\u0d07\u0d38\u0d4d\u200c\u0d32\u0d3e\u0d2e\u0d3f\u0d15\u0d4d \u0d15\u0d32\u0d23\u0d4d\u0d1f\u0d7c (\u0d09\u0d02 \u0d05\u0d7d \u0d16\u0d41\u0d31)" },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.gmtFormat", "\u0d1c\u0d3f\u0d0e\u0d02\u0d1f\u0d3f {0}" },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\u0d07\u0d38\u0d4d\u0d32\u0d3e\u0d02-\u0d38\u0d3f\u0d35\u0d3f\u0d7d \u0d15\u0d32\u0d23\u0d4d\u0d1f\u0d7c" },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -220,6 +226,7 @@ public class FormatData_ml extends ListResourceBundle {
                     "\u0d06\u0d28\u0d4d\u0d28\u0d4b \u0d21\u0d4a\u0d2e\u0d3f\u0d28\u0d3f",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -244,6 +251,8 @@ public class FormatData_ml extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -251,6 +260,7 @@ public class FormatData_ml extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u0d2e\u0d3f\u0d28\u0d3f\u0d31\u0d4d\u0d31\u0d4d" },
             { "field.era", "\u0d15\u0d3e\u0d32\u0d18\u0d1f\u0d4d\u0d1f\u0d02" },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.MonthNames",
@@ -270,6 +280,7 @@ public class FormatData_ml extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0d2e\u0d3f\u0d02\u0d17\u0d4d\u0d35\u0d4b \u0d15\u0d32\u0d23\u0d4d\u0d1f\u0d7c" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterNames },
@@ -296,18 +307,11 @@ public class FormatData_ml extends ListResourceBundle {
             },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0d07\u0d38\u0d4d\u200c\u0d32\u0d3e\u0d2e\u0d3f\u0d15\u0d4d \u0d15\u0d32\u0d23\u0d4d\u0d1f\u0d7c" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "{0} \u0d38\u0d2e\u0d2f\u0d02" },
@@ -316,26 +320,27 @@ public class FormatData_ml extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0d06\u0d2f\u0d3f\u0d30\u0d02",
-                    "00 \u0d06\u0d2f\u0d3f\u0d30\u0d02",
-                    "000 \u0d06\u0d2f\u0d3f\u0d30\u0d02",
-                    "0 \u0d26\u0d36\u0d32\u0d15\u0d4d\u0d37\u0d02",
-                    "00 \u0d26\u0d36\u0d32\u0d15\u0d4d\u0d37\u0d02",
-                    "000 \u0d26\u0d36\u0d32\u0d15\u0d4d\u0d37\u0d02",
-                    "0 \u0d32\u0d15\u0d4d\u0d37\u0d02 \u0d15\u0d4b\u0d1f\u0d3f",
-                    "00 \u0d32\u0d15\u0d4d\u0d37\u0d02 \u0d15\u0d4b\u0d1f\u0d3f",
-                    "000 \u0d32\u0d15\u0d4d\u0d37\u0d02 \u0d15\u0d4b\u0d1f\u0d3f",
-                    "0 \u0d1f\u0d4d\u0d30\u0d3f\u0d32\u0d4d\u0d2f\u0d7a",
-                    "00 \u0d1f\u0d4d\u0d30\u0d3f\u0d32\u0d4d\u0d2f\u0d7a",
-                    "000 \u0d1f\u0d4d\u0d30\u0d3f\u0d32\u0d4d\u0d2f\u0d7a",
+                    "{one:0' '\u0d06\u0d2f\u0d3f\u0d30\u0d02 other:0' '\u0d06\u0d2f\u0d3f\u0d30\u0d02}",
+                    "{one:00' '\u0d06\u0d2f\u0d3f\u0d30\u0d02 other:00' '\u0d06\u0d2f\u0d3f\u0d30\u0d02}",
+                    "{one:000' '\u0d06\u0d2f\u0d3f\u0d30\u0d02 other:000' '\u0d06\u0d2f\u0d3f\u0d30\u0d02}",
+                    "{one:0' '\u0d26\u0d36\u0d32\u0d15\u0d4d\u0d37\u0d02 other:0' '\u0d26\u0d36\u0d32\u0d15\u0d4d\u0d37\u0d02}",
+                    "{one:00' '\u0d26\u0d36\u0d32\u0d15\u0d4d\u0d37\u0d02 other:00' '\u0d26\u0d36\u0d32\u0d15\u0d4d\u0d37\u0d02}",
+                    "{one:000' '\u0d26\u0d36\u0d32\u0d15\u0d4d\u0d37\u0d02 other:000' '\u0d26\u0d36\u0d32\u0d15\u0d4d\u0d37\u0d02}",
+                    "{one:0' '\u0d32\u0d15\u0d4d\u0d37\u0d02' '\u0d15\u0d4b\u0d1f\u0d3f other:0' '\u0d32\u0d15\u0d4d\u0d37\u0d02' '\u0d15\u0d4b\u0d1f\u0d3f}",
+                    "{one:00' '\u0d32\u0d15\u0d4d\u0d37\u0d02' '\u0d15\u0d4b\u0d1f\u0d3f other:00' '\u0d32\u0d15\u0d4d\u0d37\u0d02' '\u0d15\u0d4b\u0d1f\u0d3f}",
+                    "{one:000' '\u0d32\u0d15\u0d4d\u0d37\u0d02' '\u0d15\u0d4b\u0d1f\u0d3f other:000' '\u0d32\u0d15\u0d4d\u0d37\u0d02' '\u0d15\u0d4b\u0d1f\u0d3f}",
+                    "{one:0' '\u0d1f\u0d4d\u0d30\u0d3f\u0d32\u0d4d\u0d2f\u0d7a other:0' '\u0d1f\u0d4d\u0d30\u0d3f\u0d32\u0d4d\u0d2f\u0d7a}",
+                    "{one:00' '\u0d1f\u0d4d\u0d30\u0d3f\u0d32\u0d4d\u0d2f\u0d7a other:00' '\u0d1f\u0d4d\u0d30\u0d3f\u0d32\u0d4d\u0d2f\u0d7a}",
+                    "{one:000' '\u0d1f\u0d4d\u0d30\u0d3f\u0d32\u0d4d\u0d2f\u0d7a other:000' '\u0d1f\u0d4d\u0d30\u0d3f\u0d32\u0d4d\u0d2f\u0d7a}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "standalone.DayNarrows",
                 new String[] {
                     "\u0d1e\u0d3e",
@@ -347,7 +352,8 @@ public class FormatData_ml extends ListResourceBundle {
                     "\u0d36",
                 }
             },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "mlym.NumberElements",
                 new String[] {
                     ".",
@@ -361,6 +367,8 @@ public class FormatData_ml extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "TimePatterns", metaValue_TimePatterns },
@@ -369,6 +377,7 @@ public class FormatData_ml extends ListResourceBundle {
             { "field.zone", "\u0d38\u0d2e\u0d2f \u0d2e\u0d47\u0d16\u0d32" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.narrow.Eras", metaValue_java_time_roc_Eras },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
@@ -380,39 +389,50 @@ public class FormatData_ml extends ListResourceBundle {
             { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterNames },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "\u0d06\u0d34\u0d4d\u0d1a" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "mlym.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "short.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0B",
-                    "00B",
-                    "000B",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{one:0K other:0K}",
+                    "{one:00K other:00K}",
+                    "{one:000K other:000K}",
+                    "{one:0M other:0M}",
+                    "{one:00M other:00M}",
+                    "{one:000M other:000M}",
+                    "{one:0B other:0B}",
+                    "{one:00B other:00B}",
+                    "{one:000B other:000B}",
+                    "{one:0T other:0T}",
+                    "{one:00T other:00T}",
+                    "{one:000T other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "{0} \u0d21\u0d47\u0d32\u0d48\u0d31\u0d4d\u0d31\u0d4d \u0d38\u0d2e\u0d2f\u0d02" },
             { "DatePatterns",
                 new String[] {
@@ -457,6 +477,14 @@ public class FormatData_ml extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0d2c\u0d41\u0d26\u0d4d\u0d27\u0d2e\u0d24\u0d15\u0d32\u0d23\u0d4d\u0d1f\u0d7c" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
