@@ -229,6 +229,8 @@ public class FormatData_mn extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -247,13 +249,6 @@ public class FormatData_mn extends ListResourceBundle {
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayAbbreviations },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u044b\u043d \u0446\u0430\u0433\u043b\u0430\u0432\u0430\u0440" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -265,18 +260,18 @@ public class FormatData_mn extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u043c\u044f\u043d\u0433\u0430",
-                    "00 \u043c\u044f\u043d\u0433\u0430",
-                    "000 \u043c\u044f\u043d\u0433\u0430",
-                    "0 \u0441\u0430\u044f",
-                    "00 \u0441\u0430\u044f",
-                    "000 \u0441\u0430\u044f",
-                    "0 \u0442\u044d\u0440\u0431\u0443\u043c",
-                    "00 \u0442\u044d\u0440\u0431\u0443\u043c",
-                    "000 \u0442\u044d\u0440\u0431\u0443\u043c",
-                    "0 \u0438\u0445 \u043d\u0430\u044f\u0434",
-                    "00 \u0438\u0445 \u043d\u0430\u044f\u0434",
-                    "000 \u0438\u0445 \u043d\u0430\u044f\u0434",
+                    "{one:0' '\u043c\u044f\u043d\u0433\u0430 other:0' '\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:00' '\u043c\u044f\u043d\u0433\u0430 other:00' '\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:000' '\u043c\u044f\u043d\u0433\u0430 other:000' '\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:0' '\u0441\u0430\u044f other:0' '\u0441\u0430\u044f}",
+                    "{one:00' '\u0441\u0430\u044f other:00' '\u0441\u0430\u044f}",
+                    "{one:000' '\u0441\u0430\u044f other:000' '\u0441\u0430\u044f}",
+                    "{one:0' '\u0442\u044d\u0440\u0431\u0443\u043c other:0' '\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:00' '\u0442\u044d\u0440\u0431\u0443\u043c other:00' '\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:000' '\u0442\u044d\u0440\u0431\u0443\u043c other:000' '\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:0' '\u0438\u0445' '\u043d\u0430\u044f\u0434 other:0' '\u0438\u0445' '\u043d\u0430\u044f\u0434}",
+                    "{one:00' '\u0438\u0445' '\u043d\u0430\u044f\u0434 other:00' '\u0438\u0445' '\u043d\u0430\u044f\u0434}",
+                    "{one:000' '\u0438\u0445' '\u043d\u0430\u044f\u0434 other:000' '\u0438\u0445' '\u043d\u0430\u044f\u0434}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -323,26 +318,26 @@ public class FormatData_mn extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u043c\u044f\u043d\u0433\u0430",
-                    "00\u00a0\u043c\u044f\u043d\u0433\u0430",
-                    "000\u00a0\u043c\u044f\u043d\u0433\u0430",
-                    "0\u00a0\u0441\u0430\u044f",
-                    "00\u00a0\u0441\u0430\u044f",
-                    "000\u00a0\u0441\u0430\u044f",
-                    "0\u00a0\u0442\u044d\u0440\u0431\u0443\u043c",
-                    "00\u00a0\u0442\u044d\u0440\u0431\u0443\u043c",
-                    "000\u0422",
-                    "0\u0418\u041d",
-                    "00\u0418\u041d",
-                    "000\u0418\u041d",
+                    "{one:0\u00a0\u043c\u044f\u043d\u0433\u0430 other:0\u00a0\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:00\u00a0\u043c\u044f\u043d\u0433\u0430 other:00\u00a0\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:000\u00a0\u043c\u044f\u043d\u0433\u0430 other:000\u00a0\u043c\u044f\u043d\u0433\u0430}",
+                    "{one:0\u00a0\u0441\u0430\u044f other:0\u00a0\u0441\u0430\u044f}",
+                    "{one:00\u00a0\u0441\u0430\u044f other:00\u00a0\u0441\u0430\u044f}",
+                    "{one:000\u00a0\u0441\u0430\u044f other:000\u00a0\u0441\u0430\u044f}",
+                    "{one:0\u00a0\u0442\u044d\u0440\u0431\u0443\u043c other:0\u00a0\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:00\u00a0\u0442\u044d\u0440\u0431\u0443\u043c other:00\u00a0\u0442\u044d\u0440\u0431\u0443\u043c}",
+                    "{one:000\u0422 other:000\u0422}",
+                    "{one:0\u0418\u041d other:0\u0418\u041d}",
+                    "{one:00\u0418\u041d other:00\u0418\u041d}",
+                    "{one:000\u0418\u041d other:000\u0418\u041d}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0}-\u043d \u0437\u0443\u043d\u044b \u0446\u0430\u0433" },
             { "DatePatterns",
                 new String[] {
-                    "y.MM.dd, EEEE",
-                    "y.MM.dd",
+                    "y '\u043e\u043d\u044b' MMMM'\u044b\u043d' d, EEEE '\u0433\u0430\u0440\u0430\u0433'",
+                    "y '\u043e\u043d\u044b' MMMM'\u044b\u043d' d",
                     "y '\u043e\u043d\u044b' MMM'\u044b\u043d' d",
                     "y.MM.dd",
                 }
@@ -380,6 +375,14 @@ public class FormatData_mn extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "\u00a4\u00a0#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayAbbreviations },
             { "japanese.DayNarrows", metaValue_DayAbbreviations },
             { "QuarterNames", metaValue_QuarterNames },
