@@ -202,6 +202,10 @@ public class FormatData_pa extends ListResourceBundle {
                "\u0a06\u0a30.\u0a13.\u0a38\u0a40 \u0a24\u0a4b\u0a02 \u0a2a\u0a39\u0a3f\u0a32\u0a3e\u0a02",
                "\u0a2e\u0a3f\u0a70\u0a17",
             };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "\u0a17\u0a30\u0a47\u0a17\u0a4b\u0a30\u0a40\u0a05\u0a28 \u0a15\u0a48\u0a32\u0a70\u0a21\u0a30";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -220,6 +224,8 @@ public class FormatData_pa extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -246,12 +252,14 @@ public class FormatData_pa extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "\u0a08\u0a38\u0a35\u0a40 \u0a2a\u0a42\u0a30\u0a35",
                     "\u0a08\u0a38\u0a35\u0a40 \u0a38\u0a70\u0a28",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -277,6 +285,8 @@ public class FormatData_pa extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -294,6 +304,8 @@ public class FormatData_pa extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.DayNames", metaValue_DayNames },
@@ -319,23 +331,34 @@ public class FormatData_pa extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0a2e\u0a3f\u0a70\u0a17\u0a42\u0a13 \u0a15\u0a48\u0a32\u0a70\u0a21\u0a30" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "\u0a2e\u0a39\u0a40\u0a28\u0a3e" },
+            { "arabext.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4#,##,##0.00",
+                    "#,##,##0%",
+                    "",
+                }
+            },
             { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "\u0a38\u0a15\u0a3f\u0a70\u0a1f" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "calendarname.islamic", "\u0a07\u0a38\u0a32\u0a3e\u0a2e\u0a40 \u0a15\u0a48\u0a32\u0a70\u0a21\u0a30" },
+            { "guru.NumberPatterns",
                 new String[] {
                     "#,##,##0.###",
                     "\u00a4\u00a0#,##,##0.00",
                     "#,##,##0%",
+                    "",
                 }
             },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "calendarname.islamic", "\u0a07\u0a38\u0a32\u0a3e\u0a2e\u0a40 \u0a15\u0a48\u0a32\u0a70\u0a21\u0a30" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -347,18 +370,18 @@ public class FormatData_pa extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0a39\u0a1c\u0a3c\u0a3e\u0a30",
-                    "00 \u0a39\u0a1c\u0a3c\u0a3e\u0a30",
-                    "0 \u0a32\u0a71\u0a16",
-                    "00 \u0a32\u0a71\u0a16",
-                    "0 \u0a15\u0a30\u0a4b\u0a5c",
-                    "00 \u0a15\u0a30\u0a4b\u0a5c",
-                    "0 \u0a05\u0a30\u0a2c",
-                    "00 \u0a05\u0a30\u0a2c",
-                    "0 \u0a16\u0a30\u0a2c",
-                    "00 \u0a16\u0a30\u0a2c",
-                    "0 \u0a28\u0a40\u0a32",
-                    "00 \u0a28\u0a40\u0a32",
+                    "{one:0' '\u0a39\u0a1c\u0a3c\u0a3e\u0a30 other:0' '\u0a39\u0a1c\u0a3c\u0a3e\u0a30}",
+                    "{one:00' '\u0a39\u0a1c\u0a3c\u0a3e\u0a30 other:00' '\u0a39\u0a1c\u0a3c\u0a3e\u0a30}",
+                    "{one:0' '\u0a32\u0a71\u0a16 other:0' '\u0a32\u0a71\u0a16}",
+                    "{one:00' '\u0a32\u0a71\u0a16 other:00' '\u0a32\u0a71\u0a16}",
+                    "{one:0' '\u0a15\u0a30\u0a4b\u0a5c other:0' '\u0a15\u0a30\u0a4b\u0a5c}",
+                    "{one:00' '\u0a15\u0a30\u0a4b\u0a5c other:00' '\u0a15\u0a30\u0a4b\u0a5c}",
+                    "{one:0' '\u0a05\u0a30\u0a2c other:0' '\u0a05\u0a30\u0a2c}",
+                    "{one:00' '\u0a05\u0a30\u0a2c other:00' '\u0a05\u0a30\u0a2c}",
+                    "{one:0' '\u0a16\u0a30\u0a2c other:0' '\u0a16\u0a30\u0a2c}",
+                    "{one:00' '\u0a16\u0a30\u0a2c other:00' '\u0a16\u0a30\u0a2c}",
+                    "{one:0' '\u0a28\u0a40\u0a32 other:0' '\u0a28\u0a40\u0a32}",
+                    "{one:00' '\u0a28\u0a40\u0a32 other:00' '\u0a28\u0a40\u0a32}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -392,6 +415,8 @@ public class FormatData_pa extends ListResourceBundle {
             { "field.weekday", "\u0a39\u0a2b\u0a3c\u0a24\u0a47 \u0a26\u0a3e \u0a26\u0a3f\u0a28" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
@@ -422,18 +447,18 @@ public class FormatData_pa extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0a39\u0a1c\u0a3c\u0a3e\u0a30",
-                    "00\u00a0\u0a39\u0a1c\u0a3c\u0a3e\u0a30",
-                    "0\u00a0\u0a32\u0a71\u0a16",
-                    "00\u00a0\u0a32\u0a71\u0a16",
-                    "0\u00a0\u0a15\u0a30\u0a4b\u0a5c",
-                    "00\u00a0\u0a15\u0a30\u0a4b\u0a5c",
-                    "0\u00a0\u0a05\u0a30\u0a2c",
-                    "00\u00a0\u0a05\u0a30\u0a2c",
-                    "0\u00a0\u0a16\u0a30\u0a2c",
-                    "00\u00a0\u0a16\u0a30\u0a2c",
-                    "0\u00a0\u0a28\u0a40\u0a32",
-                    "00\u00a0\u0a28\u0a40\u0a32",
+                    "{one:0\u00a0\u0a39\u0a1c\u0a3c\u0a3e\u0a30 other:0\u00a0\u0a39\u0a1c\u0a3c\u0a3e\u0a30}",
+                    "{one:00\u00a0\u0a39\u0a1c\u0a3c\u0a3e\u0a30 other:00\u00a0\u0a39\u0a1c\u0a3c\u0a3e\u0a30}",
+                    "{one:0\u00a0\u0a32\u0a71\u0a16 other:0\u00a0\u0a32\u0a71\u0a16}",
+                    "{one:00\u00a0\u0a32\u0a71\u0a16 other:00\u00a0\u0a32\u0a71\u0a16}",
+                    "{one:0\u00a0\u0a15\u0a30\u0a4b\u0a5c other:0\u00a0\u0a15\u0a30\u0a4b\u0a5c}",
+                    "{one:00\u00a0\u0a15\u0a30\u0a4b\u0a5c other:00\u00a0\u0a15\u0a30\u0a4b\u0a5c}",
+                    "{one:0\u00a0\u0a05\u0a30\u0a2c other:0\u00a0\u0a05\u0a30\u0a2c}",
+                    "{one:00\u00a0\u0a05\u0a30\u0a2c other:00\u00a0\u0a05\u0a30\u0a2c}",
+                    "{one:0\u00a0\u0a16\u0a30\u0a2c other:0\u00a0\u0a16\u0a30\u0a2c}",
+                    "{one:00\u00a0\u0a16\u0a30\u0a2c other:00\u00a0\u0a16\u0a30\u0a2c}",
+                    "{one:0\u00a0\u0a28\u0a40\u0a32 other:0\u00a0\u0a28\u0a40\u0a32}",
+                    "{one:00\u00a0\u0a28\u0a40\u0a32 other:00\u00a0\u0a28\u0a40\u0a32}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -469,9 +494,19 @@ public class FormatData_pa extends ListResourceBundle {
                     "",
                 }
             },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0a2c\u0a4b\u0a27\u0a40 \u0a15\u0a48\u0a32\u0a70\u0a21\u0a30" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##,##0.###",
+                    "\u00a4\u00a0#,##,##0.00",
+                    "#,##,##0%",
+                    "\u00a4\u00a0#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
