@@ -174,6 +174,10 @@ public class FormatData_to extends ListResourceBundle {
                "3",
                "4",
             };
+        final String[] metaValue_buddhist_narrow_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE d MMMM y G",
                "d MMMM y G",
@@ -186,11 +190,13 @@ public class FormatData_to extends ListResourceBundle {
                "d MMM y GGGG",
                "d/M/yy G",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String metaValue_calendarname_gregorian = "fakakelekolia";
+        final String[] metaValue_arabext_NumberPatterns = new String[] {
+               "#,##0.###",
+               "\u00a4\u00a0#,##0.00",
+               "#,##0%",
+               "",
+            };
         final String[] metaValue_brah_NumberElements = new String[] {
                ".",
                ",",
@@ -203,6 +209,8 @@ public class FormatData_to extends ListResourceBundle {
                "\u2030",
                "\u221e",
                "NaN",
+               "",
+               "",
             };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -220,10 +228,13 @@ public class FormatData_to extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
             { "AmPmMarkers", metaValue_AmPmMarkers },
+            { "osma.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
@@ -240,11 +251,15 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
+            { "mtei.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "fakamohameti-sivile" },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
+            { "takr.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "mymr.NumberElements",
                 new String[] {
                     ".",
@@ -258,6 +273,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.TimePatterns", metaValue_TimePatterns },
@@ -275,8 +292,11 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
+            { "gonm.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "timezone.regionFormat.standard", "{0} Taimi totonu" },
             { "tamldec.NumberElements",
                 new String[] {
@@ -291,6 +311,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "calendarname.japanese", "fakasiapani" },
@@ -307,6 +329,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.MonthNames", metaValue_MonthNames },
@@ -325,6 +349,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "long.Eras",
@@ -333,6 +359,7 @@ public class FormatData_to extends ListResourceBundle {
                     "ta\u02bbu \u02bbo S\u012bs\u016b",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "saur.NumberElements",
                 new String[] {
                     ".",
@@ -346,11 +373,14 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
+            { "cakm.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "DateTimePatterns",
                 new String[] {
                     "{1}, {0}",
@@ -372,6 +402,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "TF",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -389,6 +421,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.DayNames", metaValue_DayNames },
@@ -396,6 +430,8 @@ public class FormatData_to extends ListResourceBundle {
             { "field.era", "kuonga" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
+            { "bali.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "lana.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "cham.NumberElements",
                 new String[] {
@@ -410,8 +446,12 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "saur.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "arab.NumberElements",
                 new String[] {
                     "\u066b",
@@ -425,8 +465,11 @@ public class FormatData_to extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
+            { "beng.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "shrd.NumberElements", metaValue_brah_NumberElements },
             { "takr.NumberElements", metaValue_brah_NumberElements },
             { "calendarname.roc", "fakalepupelika siaina" },
@@ -444,24 +487,23 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "sund.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "field.month", "m\u0101hina" },
+            { "arabext.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "osma.NumberElements", metaValue_brah_NumberElements },
             { "field.second", "sekoni" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
-                    "#,##0%",
-                }
-            },
+            { "vaii.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "fakamohameti" },
             { "gonm.NumberElements", metaValue_brah_NumberElements },
+            { "guru.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "knda.NumberElements",
                 new String[] {
                     ".",
@@ -475,6 +517,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "bali.NumberElements",
@@ -490,10 +534,13 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
+            { "sora.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "brah.NumberElements", metaValue_brah_NumberElements },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Taimi {0}" },
@@ -502,22 +549,22 @@ public class FormatData_to extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 afe",
-                    "0 mano",
-                    "0 kilu",
-                    "0 miliona",
-                    "00 miliona",
-                    "000 miliona",
-                    "0 piliona",
-                    "00 piliona",
-                    "000 piliona",
-                    "0 tiliona",
-                    "00 tiliona",
-                    "000 tiliona",
+                    "{other:0' 'afe}",
+                    "{other:0' 'mano}",
+                    "{other:0' 'kilu}",
+                    "{other:0' 'miliona}",
+                    "{other:00' 'miliona}",
+                    "{other:000' 'miliona}",
+                    "{other:0' 'piliona}",
+                    "{other:00' 'piliona}",
+                    "{other:000' 'piliona}",
+                    "{other:0' 'tiliona}",
+                    "{other:00' 'tiliona}",
+                    "{other:000' 'tiliona}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "standalone.QuarterNames",
                 new String[] {
                     "kuata 1",
@@ -539,12 +586,17 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "tibt.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "khmr.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "orya.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "mymrshan.NumberElements",
                 new String[] {
                     ".",
@@ -558,6 +610,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
@@ -574,6 +628,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "java.NumberElements",
@@ -589,6 +645,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "TimePatterns", metaValue_TimePatterns },
@@ -605,8 +663,11 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
+            { "gujr.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "fullwide.NumberElements",
                 new String[] {
                     ".",
@@ -620,9 +681,13 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "limb.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "hanidec.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "khmr.NumberElements",
                 new String[] {
                     ".",
@@ -636,10 +701,20 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "field.zone", "taimi fakavahe" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "arab.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "",
+                }
+            },
             { "laoo.NumberElements",
                 new String[] {
                     ".",
@@ -653,6 +728,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "sund.NumberElements",
@@ -668,8 +745,11 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
+            { "telu.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "thai.NumberElements",
                 new String[] {
                     ".",
@@ -683,9 +763,13 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_narrow_AmPmMarkers },
             { "Eras", metaValue_Eras },
+            { "hanidec.NumberElements", metaValue_brah_NumberElements },
             { "kali.NumberElements",
                 new String[] {
                     ".",
@@ -699,10 +783,15 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.DayNames", metaValue_DayNames },
+            { "lepc.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "mymrshan.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "nkoo.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "mong.NumberElements",
                 new String[] {
                     ".",
@@ -716,14 +805,23 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
+            { "lanatham.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "\u02bbaho \u02bbo e uike" },
+            { "brah.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "java.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "thai.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "fullwide.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "mong.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "tamldec.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "telu.NumberElements",
                 new String[] {
                     ".",
@@ -737,8 +835,11 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
+            { "mymr.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "nkoo.NumberElements",
                 new String[] {
                     ".",
@@ -752,9 +853,12 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "cakm.NumberElements", metaValue_brah_NumberElements },
+            { "olck.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "tibt.NumberElements",
                 new String[] {
                     ".",
@@ -768,9 +872,12 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.DayNames", metaValue_DayNames },
+            { "knda.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "lanatham.NumberElements",
@@ -786,11 +893,15 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
             { "sora.NumberElements", metaValue_brah_NumberElements },
+            { "laoo.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "talu.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "field.week", "uike" },
             { "gujr.NumberElements",
                 new String[] {
@@ -805,6 +916,8 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
@@ -823,9 +936,12 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.DayNarrows", metaValue_DayNarrows },
+            { "shrd.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "orya.NumberElements",
                 new String[] {
                     ".",
@@ -839,28 +955,31 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "mlym.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "short.CompactNumberPatterns",
                 new String[] {
                     "",
                     "",
                     "",
-                    "0a",
-                    "0m",
-                    "0k",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0P",
-                    "00P",
-                    "000P",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{other:0a}",
+                    "{other:0m}",
+                    "{other:0k}",
+                    "{other:0M}",
+                    "{other:00M}",
+                    "{other:000M}",
+                    "{other:0P}",
+                    "{other:00P}",
+                    "{other:000P}",
+                    "{other:0T}",
+                    "{other:00T}",
+                    "{other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -874,6 +993,7 @@ public class FormatData_to extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "cham.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
@@ -891,15 +1011,27 @@ public class FormatData_to extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "calendarname.buddhist", "fakaputa" },
+            { "kali.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "\u00a4\u00a0#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "deva.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
