@@ -151,6 +151,27 @@ public class FormatData_vi extends ListResourceBundle {
                "Tr\u01b0\u1edbc CN",
                "sau CN",
             };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
+        final String[] metaValue_buddhist_MonthNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+               "5",
+               "6",
+               "7",
+               "8",
+               "9",
+               "10",
+               "11",
+               "12",
+               "",
+            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
@@ -173,25 +194,9 @@ public class FormatData_vi extends ListResourceBundle {
                "dd-MM-y GGGG",
                "dd/MM/y G",
             };
-        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
-               "sau CN",
-               "Meiji",
-               "Taish\u014d",
-               "Sh\u014dwa",
-               "Heisei",
-               "Reiwa",
-            };
-        final String[] metaValue_java_time_japanese_narrow_Eras = new String[] {
-               "sau CN",
-               "M",
-               "T",
-               "S",
-               "H",
-               "R",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "Tr\u01b0\u1edbc R.O.C",
-               "",
+               "R.O.C.",
             };
         final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
@@ -200,24 +205,8 @@ public class FormatData_vi extends ListResourceBundle {
         final String metaValue_calendarname_gregorian = "L\u1ecbch Gregory";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
-            { "java.time.japanese.narrow.Eras", metaValue_java_time_japanese_narrow_Eras },
             { "field.year", "N\u0103m" },
             { "calendarname.islamic-umalqura", "L\u1ecbch H\u1ed3i Gi\u00e1o - Umm al-Qura" },
-            { "arabext.NumberElements",
-                new String[] {
-                    "\u066b",
-                    "\u066c",
-                    "\u061b",
-                    "\u066a",
-                    "\u06f0",
-                    "#",
-                    "\u200e-\u200e",
-                    "\u00d7\u06f1\u06f0^",
-                    "\u0609",
-                    "\u221e",
-                    "NaN",
-                }
-            },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
@@ -231,9 +220,10 @@ public class FormatData_vi extends ListResourceBundle {
             },
             { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
-            { "japanese.narrow.Eras", metaValue_java_time_japanese_narrow_Eras },
+            { "roc.MonthNarrows", metaValue_buddhist_MonthNarrows },
             { "calendarname.islamic-civil", "L\u1ecbch Islamic-Civil" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
@@ -250,6 +240,7 @@ public class FormatData_vi extends ListResourceBundle {
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -275,6 +266,8 @@ public class FormatData_vi extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.DatePatterns",
@@ -287,25 +280,10 @@ public class FormatData_vi extends ListResourceBundle {
             },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "Ph\u00fat" },
-            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "th\u1eddi \u0111\u1ea1i" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "SA/CH" },
-            { "arab.NumberElements",
-                new String[] {
-                    "\u066b",
-                    "\u066c",
-                    "\u061b",
-                    "\u066a\u061c",
-                    "\u0660",
-                    "#",
-                    "\u061c-",
-                    "\u0627\u0633",
-                    "\u0609",
-                    "\u221e",
-                    "NaN",
-                }
-            },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "L\u1ecbch Trung Hoa D\u00e2n Qu\u1ed1c" },
             { "islamic.DatePatterns",
                 new String[] {
@@ -318,23 +296,16 @@ public class FormatData_vi extends ListResourceBundle {
             { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "Th\u00e1ng" },
-            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "Gi\u00e2y" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "L\u1ecbch H\u1ed3i Gi\u00e1o" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
                 new String[] {
                     "Thg 1",
@@ -358,18 +329,18 @@ public class FormatData_vi extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 ngh\u00ecn",
-                    "00 ngh\u00ecn",
-                    "000 ngh\u00ecn",
-                    "0 tri\u1ec7u",
-                    "00 tri\u1ec7u",
-                    "000 tri\u1ec7u",
-                    "0 t\u1ef7",
-                    "00 t\u1ef7",
-                    "000 t\u1ef7",
-                    "0 ngh\u00ecn t\u1ef7",
-                    "00 ngh\u00ecn t\u1ef7",
-                    "000 ngh\u00ecn t\u1ef7",
+                    "{other:0' 'ngh\u00ecn}",
+                    "{other:00' 'ngh\u00ecn}",
+                    "{other:000' 'ngh\u00ecn}",
+                    "{other:0' 'tri\u1ec7u}",
+                    "{other:00' 'tri\u1ec7u}",
+                    "{other:000' 'tri\u1ec7u}",
+                    "{other:0' 't\u1ef7}",
+                    "{other:00' 't\u1ef7}",
+                    "{other:000' 't\u1ef7}",
+                    "{other:0' 'ngh\u00ecn' 't\u1ef7}",
+                    "{other:00' 'ngh\u00ecn' 't\u1ef7}",
+                    "{other:000' 'ngh\u00ecn' 't\u1ef7}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -382,12 +353,14 @@ public class FormatData_vi extends ListResourceBundle {
                     "qu\u00fd 4",
                 }
             },
+            { "japanese.MonthNarrows", metaValue_buddhist_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "M\u00fai gi\u1edd" },
@@ -419,11 +392,11 @@ public class FormatData_vi extends ListResourceBundle {
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "java.time.japanese.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
             { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "Tu\u1ea7n" },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
+            { "buddhist.MonthNarrows", metaValue_buddhist_MonthNarrows },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
@@ -434,18 +407,18 @@ public class FormatData_vi extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0N",
-                    "00\u00a0N",
-                    "000\u00a0N",
-                    "0\u00a0Tr",
-                    "00\u00a0Tr",
-                    "000\u00a0Tr",
-                    "0\u00a0T",
-                    "00\u00a0T",
-                    "000\u00a0T",
-                    "0\u00a0NT",
-                    "00\u00a0NT",
-                    "000\u00a0NT",
+                    "{other:0\u00a0N}",
+                    "{other:00\u00a0N}",
+                    "{other:000\u00a0N}",
+                    "{other:0\u00a0Tr}",
+                    "{other:00\u00a0Tr}",
+                    "{other:000\u00a0Tr}",
+                    "{other:0\u00a0T}",
+                    "{other:00\u00a0T}",
+                    "{other:000\u00a0T}",
+                    "{other:0\u00a0NT}",
+                    "{other:00\u00a0NT}",
+                    "{other:000\u00a0NT}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -460,6 +433,7 @@ public class FormatData_vi extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "Gi\u1edd" },
@@ -482,11 +456,19 @@ public class FormatData_vi extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
-            { "japanese.Eras", metaValue_java_time_japanese_long_Eras },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
