@@ -71,8 +71,148 @@ public class CurrencyNames_te extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
+            { "CNH", "CNH" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LTL", "LTL" },
+            { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MRU", "MRU" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
+            { "STN", "STN" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
             { "USD", "$" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEF", "VEF" },
+            { "VES", "VES" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "aed", "\u0c2f\u0c41\u0c28\u0c48\u0c1f\u0c46\u0c21\u0c4d \u0c06\u0c30\u0c2c\u0c4d \u0c0e\u0c2e\u0c3f\u0c30\u0c47\u0c1f\u0c4d\u0c38\u0c4d \u0c26\u0c3f\u0c30\u0c3e\u0c2e\u0c4d" },
             { "afn", "\u0c06\u0c2b\u0c4d\u0c18\u0c3e\u0c28\u0c4d \u0c06\u0c2b\u0c4d\u0c18\u0c3e\u0c28\u0c3f" },
             { "all", "\u0c06\u0c32\u0c4d\u0c2c\u0c47\u0c28\u0c3f\u0c2f\u0c28\u0c4d \u0c32\u0c47\u0c15\u0c4d" },
@@ -135,7 +275,7 @@ public class CurrencyNames_te extends OpenListResourceBundle {
             { "htg", "\u0c39\u0c48\u0c1f\u0c3f\u0c2f\u0c28\u0c4d \u0c17\u0c4d\u0c35\u0c4b\u0c30\u0c4d\u0c21\u0c47" },
             { "huf", "\u0c39\u0c02\u0c17\u0c47\u0c30\u0c3f\u0c2f\u0c28\u0c4d \u0c2b\u0c4b\u0c30\u0c3f\u0c02\u0c1f\u0c4d" },
             { "idr", "\u0c07\u0c02\u0c21\u0c4b\u0c28\u0c47\u0c37\u0c3f\u0c2f\u0c3e \u0c30\u0c42\u0c2a\u0c3e\u0c2f\u0c3f" },
-            { "ils", "\u0c10\u0c30\u0c3e\u0c2f\u0c3f\u0c32\u0c3f \u0c28\u0c4d\u0c2f\u0c42 \u0c37\u0c46\u0c15\u0c4d\u0c2f\u0c46\u0c32\u0c4d" },
+            { "ils", "\u0c07\u0c1c\u0c4d\u0c30\u0c3e\u0c2f\u0c47\u0c32\u0c40 \u0c28\u0c4d\u0c2f\u0c42 \u0c37\u0c46\u0c15\u0c46\u0c32\u0c4d" },
             { "inr", "\u0c30\u0c42\u0c2a\u0c3e\u0c2f\u0c3f" },
             { "iqd", "\u0c07\u0c30\u0c3e\u0c15\u0c40 \u0c26\u0c40\u0c28\u0c3e\u0c30\u0c4d" },
             { "irr", "\u0c07\u0c30\u0c3e\u0c28\u0c3f\u0c2f\u0c28\u0c4d \u0c30\u0c40\u0c2f\u0c32\u0c4d" },
@@ -214,7 +354,7 @@ public class CurrencyNames_te extends OpenListResourceBundle {
             { "tmt", "\u0c24\u0c41\u0c30\u0c4d\u0c15\u0c4d\u200c\u0c2e\u0c46\u0c28\u0c3f\u0c38\u0c4d\u0c25\u0c3e\u0c28\u0c3f \u0c2e\u0c28\u0c3e\u0c1f\u0c4d" },
             { "tnd", "\u0c24\u0c41\u0c28\u0c40\u0c37\u0c3f\u0c2f\u0c28\u0c4d \u0c26\u0c40\u0c28\u0c3e\u0c30\u0c4d" },
             { "top", "\u0c1f\u0c4b\u0c02\u0c17\u0c3e\u0c28\u0c4d \u0c2a\u0c3e\u0c02\u02bb\u0c17\u0c3e" },
-            { "try", "\u0c24\u0c41\u0c30\u0c4d\u0c15\u0c3f\u0c37\u0c4d \u0c32\u0c3f\u0c30\u0c3e" },
+            { "try", "\u0c1f\u0c30\u0c4d\u0c15\u0c3f\u0c38\u0c4d \u0c32\u0c40\u0c30\u0c3e" },
             { "ttd", "\u0c1f\u0c4d\u0c30\u0c3f\u0c28\u0c3f\u0c21\u0c3e\u0c21\u0c4d \u0c2e\u0c30\u0c3f\u0c2f\u0c41 \u0c1f\u0c4a\u0c2c\u0c3e\u0c17\u0c4b \u0c21\u0c3e\u0c32\u0c30\u0c4d" },
             { "twd", "\u0c15\u0c4d\u0c30\u0c4a\u0c24\u0c4d\u0c24 \u0c24\u0c48\u0c35\u0c3e\u0c28\u0c4d \u0c21\u0c3e\u0c32\u0c30\u0c4d" },
             { "tzs", "\u0c1f\u0c3e\u0c02\u0c1c\u0c3e\u0c28\u0c3f\u0c2f\u0c28\u0c4d \u0c37\u0c3f\u0c32\u0c4d\u0c32\u0c3f\u0c02\u0c17\u0c4d" },
