@@ -124,7 +124,7 @@ public class LocaleNames_chr extends OpenListResourceBundle {
             { "en_US", "\u13a0\u13b9\u13f0\u13df \u13a9\u13b5\u13cf" },
             { "AX", "\u13a3\u13b4\u13c5\u13d3 \u13da\u13a6\u13da\u13db\u13a2" },
             { "AZ", metaValue_AZ },
-            { "BA", "\u13c9\u13cf\u13c2\u13a0 & \u13b2\u13e4\u13aa\u13eb" },
+            { "BA", "\u13c9\u13cf\u13c2\u13a0 & \u13b2\u13e4\u13aa\u13eb\u13be" },
             { "BB", "\u13c6\u13c7\u13d9\u13cd" },
             { "ceb", "\u13ce\u13c6\u13c3" },
             { "BD", "\u13c6\u13c2\u13a6\u13b5\u13d5\u13cd" },
@@ -591,7 +591,7 @@ public class LocaleNames_chr extends OpenListResourceBundle {
             { "cy", "\u13ea\u13b5\u13cf" },
             { "type.nu.ethi", "\u13a2\u13d7\u13ef\u13c8\u13a9 \u13d7\u13ce\u13cd\u13d7" },
             { "da", "\u13d5\u13c2\u13cd" },
-            { "pt_PT", "\u13c9\u13e5\u13a6\u13b3 \u13c9\u13e7\u13a9\u13cd" },
+            { "pt_PT", "\u13f3\u13b3\u13c8 \u13c9\u13e7\u13a9\u13cd" },
             { "de", "\u13d9\u13a2\u13e5" },
             { "type.cf.standard", "\u13a0\u13df\u13b6\u13cd\u13d7 \u13a0\u13d5\u13b3 \u13f1\u13ac\u13c1\u13b8\u13af" },
             { "bem", "\u13c7\u13b9\u13c6" },
@@ -889,6 +889,7 @@ public class LocaleNames_chr extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u13d4\u13bb\u13b5 \u13d7\u13ce\u13cd\u13d7" },
             { "krc", "\u13a7\u13b3\u13e3\u13f1-\u13c6\u13b5\u13a7\u13b5" },
             { "inh", "\u13a2\u13c2\u13ab\u13cf" },
+            { "fa_AF", "\u13d3\u13b5" },
             { "krl", "\u13a7\u13b4\u13b5\u13a0\u13c2" },
             { "efi", "\u13a1\u13eb\u13a9" },
             { "key.nu", "\u13d7\u13ce\u13cd\u13d7" },
