@@ -125,6 +125,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "kum", "kum\u00fck" },
             { "BE", "Belgium" },
             { "gmh", "k\u00f6z\u00e9p fels\u0151 n\u00e9met" },
+            { "Sogo", "\u00d3szogd" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulg\u00e1ria" },
             { "BH", "Bahrein" },
@@ -171,6 +172,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "CY", "Ciprus" },
             { "CZ", "Csehorsz\u00e1g" },
             { "eka", "ekadzsuk" },
+            { "Sogd", "Szogd" },
             { "DE", "N\u00e9metorsz\u00e1g" },
             { "goh", "\u00f3fels\u0151 n\u00e9met" },
             { "ace", "achin\u00e9z" },
@@ -312,6 +314,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "tog", "nyugati nyasza" },
             { "type.nu.knda", "Kannada sz\u00e1mjegyek" },
             { "Kali", "Kajah li" },
+            { "Sidd", "Sziddham" },
             { "de_CH", "sv\u00e1jci feln\u00e9met" },
             { "type.co.phonetic", "Fonetikus rendez\u00e9si sorrend" },
             { "type.ca.buddhist", "Buddhista napt\u00e1r" },
@@ -373,7 +376,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "type.nu.vaii", "Vai sz\u00e1mjegyek" },
             { "MK", "\u00c9szak-Maced\u00f3nia" },
             { "ML", "Mali" },
-            { "MM", "Mianmar (Burma)" },
+            { "MM", "Mianmar" },
             { "MN", "Mong\u00f3lia" },
             { "new", "nevari" },
             { "MO", "Maka\u00f3 KKT" },
@@ -518,6 +521,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "TC", "Turks- \u00e9s Caicos-szigetek" },
             { "yav", "jangben" },
             { "TD", "Cs\u00e1d" },
+            { "Qaag", "Zawgyi" },
             { "TF", "Francia D\u00e9li Ter\u00fcletek" },
             { "TG", "Togo" },
             { "TH", "Thaif\u00f6ld" },
@@ -641,6 +645,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "dav", "taita" },
             { "Maya", "Maja hieroglif\u00e1k" },
             { "lrc", "\u00e9szaki luri" },
+            { "type.co.emoji", "Emodzsi rendez\u00e9si sorrend" },
             { "Copt", "Kopt" },
             { "nwc", "klasszikus newari" },
             { "udm", "udmurt" },
@@ -689,6 +694,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "scn", "szic\u00edliai" },
             { "aa", "afar" },
             { "ab", "abh\u00e1z" },
+            { "Aran", "Nasztalik" },
             { "ae", "aveszt\u00e1n" },
             { "af", "afrikaans" },
             { "ak", "akan" },
@@ -766,7 +772,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "type.co.big5han", "Hagyom\u00e1nyos k\u00ednai sorrend - Big5" },
             { "es", "spanyol" },
             { "et", "\u00e9szt" },
-            { "Hanb", "Hanb" },
+            { "Hanb", "Han bopomof\u00f3val" },
             { "eu", "baszk" },
             { "Buhd", "Buhid" },
             { "Hang", "Hangul" },
@@ -1073,7 +1079,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "Sylo", "Sylheti nag\u00e1ri" },
             { "ve", "venda" },
             { "type.ca.roc", "K\u00ednai k\u00f6zt\u00e1rsas\u00e1gi napt\u00e1r" },
-            { "vi", "vietnami" },
+            { "vi", "vietn\u00e1mi" },
             { "kho", "kotan\u00e9z" },
             { "khq", "kojra-cs\u00edni" },
             { "key.hc", "\u00d3raform\u00e1tum (12 \u2013 24)" },
@@ -1181,6 +1187,7 @@ public class LocaleNames_hu extends OpenListResourceBundle {
             { "type.nu.tamldec", "Tamil sz\u00e1mjegyek" },
             { "krc", "karacs\u00e1j-balk\u00e1r" },
             { "inh", "ingus" },
+            { "fa_AF", "dari" },
             { "krl", "karelai" },
             { "efi", "efik" },
             { "key.nu", "Sz\u00e1mok" },
