@@ -110,6 +110,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
         final String metaValue_VN = "Vietnam";
         final String metaValue_WS = "Samoa";
         final String metaValue_ae = "Avesta";
+        final String metaValue_ar = "Arab";
         final String metaValue_bn = "Bengali";
         final String metaValue_bo = "Tibet";
         final String metaValue_gu = "Gujarat";
@@ -125,6 +126,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
         final String metaValue_su = "Sunda";
         final String metaValue_ta = "Tamil";
         final String metaValue_te = "Telugu";
+        final String metaValue_th = "Thai";
         final String metaValue_tl = "Tagalog";
         final String metaValue_bug = "Bugis";
         final String metaValue_ccp = "Chakma";
@@ -174,7 +176,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "AM", metaValue_AM },
             { "Teng", "Tenghwar" },
             { "AO", "Angola" },
-            { "AQ", "Antartika" },
+            { "AQ", "Antarktika" },
             { "AR", "Argentina" },
             { "Prti", "Prasasti Parthia" },
             { "AS", "Samoa Amerika" },
@@ -222,7 +224,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "CF", "Republik Afrika Tengah" },
             { "CG", "Kongo - Brazzaville" },
             { "CH", "Swiss" },
-            { "CI", "Pantai Gading" },
+            { "CI", "C\u00f4te d\u2019Ivoire" },
             { "CK", "Kepulauan Cook" },
             { "CL", "Cile" },
             { "Kthi", "Kaithi" },
@@ -234,7 +236,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "CU", "Kuba" },
             { "CV", "Tanjung Verde" },
             { "CW", "Cura\u00e7ao" },
-            { "CX", "Pulau Christmas" },
+            { "CX", "Pulau Natal" },
             { "CY", metaValue_CY },
             { "type.nu.bali", "Angka Bali" },
             { "CZ", "Ceko" },
@@ -296,7 +298,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "aeb", "Arab Tunisia" },
             { "FI", "Finlandia" },
             { "FJ", metaValue_FJ },
-            { "FK", "Kepulauan Malvinas" },
+            { "FK", "Kepulauan Falkland" },
             { "FM", "Mikronesia" },
             { "key.va", "Varian Lokal" },
             { "FO", "Kepulauan Faroe" },
@@ -340,7 +342,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "zxx", "Tidak ada konten linguistik" },
             { "Jurc", "Jurchen" },
             { "Vaii", metaValue_vai },
-            { "HK", "Hong Kong SAR Tiongkok" },
+            { "HK", "Hong Kong DAK Tiongkok" },
             { "HM", "Pulau Heard dan Kepulauan McDonald" },
             { "HN", "Honduras" },
             { "HR", metaValue_HR },
@@ -350,7 +352,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "HT", "Haiti" },
             { "HU", metaValue_HU },
             { "tmh", "Tamashek" },
-            { "IC", "Kepulauan Canary" },
+            { "IC", "Kepulauan Canaria" },
             { "ID", metaValue_ID },
             { "peo", metaValue_peo },
             { "type.nu.kali", "Angka Kayah Li" },
@@ -444,6 +446,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "MF", "Saint Martin" },
             { "lam", "Lamba" },
             { "MG", "Madagaskar" },
+            { "Thai", metaValue_th },
             { "MH", "Kepulauan Marshall" },
             { "ale", "Aleut" },
             { "type.nu.vaii", "Angka Vai" },
@@ -452,13 +455,13 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "MM", "Myanmar (Burma)" },
             { "MN", metaValue_MN },
             { "new", "Newari" },
-            { "MO", "Makau SAR Tiongkok" },
+            { "MO", "Makau DAK Tiongkok" },
             { "MP", "Kepulauan Mariana Utara" },
             { "MQ", "Martinik" },
             { "MR", "Mauritania" },
             { "MS", "Montserrat" },
             { "MT", metaValue_MT },
-            { "type.m0.ungegn", "UNGEGN" },
+            { "type.m0.ungegn", "Transliterasi GEGN PBB" },
             { "MU", "Mauritius" },
             { "alt", "Altai Selatan" },
             { "MV", "Maladewa" },
@@ -603,7 +606,8 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "TC", "Kepulauan Turks dan Caicos" },
             { "yav", "Yangben" },
             { "TD", "Cad" },
-            { "TF", "Wilayah Kutub Selatan Prancis" },
+            { "Qaag", "Zawgyi" },
+            { "TF", "Wilayah Selatan Perancis" },
             { "ase", "Bahasa Isyarat Amerika" },
             { "TG", "Togo" },
             { "TH", "Thailand" },
@@ -654,10 +658,10 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "nnh", "Ngiemboon" },
             { "VA", "Vatikan" },
             { "pro", "Provencal Lama" },
-            { "VC", "Saint Vincent dan Grenadines" },
+            { "VC", "Saint Vincent dan Grenadine" },
             { "VE", "Venezuela" },
-            { "VG", "Kepulauan Virgin Inggris" },
-            { "VI", "Kepulauan Virgin A.S." },
+            { "VG", "Kepulauan Virgin Britania Raya" },
+            { "VI", "Kepulauan Virgin Amerika Serikat" },
             { "VN", metaValue_VN },
             { "VU", "Vanuatu" },
             { "nog", "Nogai" },
@@ -706,6 +710,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "type.lb.loose", "Gaya Pemisah Baris Renggang" },
             { "Deva", "Devanagari" },
             { "type.nu.geor", "Angka Georgia" },
+            { "type.co.zhuyin", "Aturan Pengurutan Zhuyin" },
             { "Hira", "Hiragana" },
             { "ZM", "Zambia" },
             { "%%PINYIN", "Pinyin Latin" },
@@ -784,16 +789,18 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "scn", "Sisilia" },
             { "aa", "Afar" },
             { "ab", "Abkhaz" },
+            { "Aran", "Nastaliq" },
             { "bbc", "Batak Toba" },
             { "ae", metaValue_ae },
             { "af", "Afrikaans" },
             { "ak", "Akan" },
             { "bbj", "Ghomala" },
             { "am", "Amharik" },
+            { "Arab", metaValue_ar },
             { "an", "Aragon" },
             { "%%SOLBA", "Dialek Stolvizza/Solbica" },
             { "Jpan", metaValue_JP },
-            { "ar", "Arab" },
+            { "ar", metaValue_ar },
             { "Hrkt", "Katakana atau Hiragana" },
             { "as", "Assam" },
             { "Lina", "Linear A" },
@@ -887,7 +894,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "bgn", "Balochi Barat" },
             { "yue", "Kanton" },
             { "fo", "Faroe" },
-            { "type.m0.bgn", "BGN" },
+            { "type.m0.bgn", "Transliterasi BGN AS" },
             { "umb", "Umbundu" },
             { "fr", metaValue_FR },
             { "sid", "Sidamo" },
@@ -916,6 +923,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "frc", "Prancis Cajun" },
             { "%%FONIPA", "Fonetik IPA" },
             { "ia", "Interlingua" },
+            { "Jamo", "Jamo" },
             { "id", metaValue_ID },
             { "type.nu.tibt", "Angka Tibet" },
             { "ie", "Interlingue" },
@@ -1036,7 +1044,6 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "om", "Oromo" },
             { "kaw", "Kawi" },
             { "or", metaValue_or },
-            { "Modi", "Modi" },
             { "os", "Ossetia" },
             { "%%ALALC97", "ALA-LC Latin, edisi 1997" },
             { "kbd", "Kabardi" },
@@ -1130,7 +1137,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "te", metaValue_te },
             { "145", "Asia Bagian Barat" },
             { "tg", "Tajik" },
-            { "th", "Thai" },
+            { "th", metaValue_th },
             { "bug", metaValue_bug },
             { "ti", "Tigrinya" },
             { "kfo", "Koro" },
@@ -1171,7 +1178,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "Sylo", "Syloti Nagri" },
             { "ve", "Venda" },
             { "Wara", "Varang Kshiti" },
-            { "type.ca.roc", "Kalendar Minguo" },
+            { "type.ca.roc", "Kalender Min-guo" },
             { "vi", metaValue_VN },
             { "kho", "Khotan" },
             { "khq", "Koyra Chiini" },
@@ -1286,6 +1293,7 @@ public class LocaleNames_in extends OpenListResourceBundle {
             { "krc", "Karachai Balkar" },
             { "inh", "Ingushetia" },
             { "kri", "Krio" },
+            { "fa_AF", "Persia Dari" },
             { "krl", "Karelia" },
             { "efi", "Efik" },
             { "key.nu", metaValue_key_nu },
