@@ -128,7 +128,7 @@ public class LocaleNames_lv extends OpenListResourceBundle {
             { "AG", "Antigva un Barbuda" },
             { "type.ca.ethiopic", "etiopie\u0161u kalend\u0101rs" },
             { "AI", "Angilja" },
-            { "key.tz", "Laika josla" },
+            { "key.tz", "laika josla" },
             { "AL", "Alb\u0101nija" },
             { "AM", "Arm\u0113nija" },
             { "AO", "Angola" },
@@ -248,7 +248,7 @@ public class LocaleNames_lv extends OpenListResourceBundle {
             { "FJ", "Fid\u017ei" },
             { "FK", "Folklenda salas" },
             { "FM", "Mikron\u0113zija" },
-            { "key.va", "Lokaliz\u0101cijas variants" },
+            { "key.va", "lokaliz\u0101cijas variants" },
             { "FO", "F\u0113ru salas" },
             { "Taml", metaValue_ta },
             { "FR", "Francija" },
@@ -382,7 +382,7 @@ public class LocaleNames_lv extends OpenListResourceBundle {
             { "MM", "Mjanma (Birma)" },
             { "MN", "Mongolija" },
             { "new", "nevaru" },
-            { "MO", "\u0136\u012bnas \u012bpa\u0161\u0101s p\u0101rvaldes apgabals Makao" },
+            { "MO", "\u0136TR \u012bpa\u0161ais administrat\u012bvais re\u0123ions Makao" },
             { "MP", "Zieme\u013cu Marianas salas" },
             { "MQ", "Martinika" },
             { "MR", "Maurit\u0101nija" },
@@ -500,7 +500,7 @@ public class LocaleNames_lv extends OpenListResourceBundle {
             { "SX", "Sintm\u0101rtena" },
             { "SY", "S\u012brija" },
             { "yao", "jao" },
-            { "SZ", "Svazilenda" },
+            { "SZ", "Svatini" },
             { "arw", "aravaku" },
             { "yap", "japie\u0161u" },
             { "TA", "Tristana da Ku\u0146as salas" },
@@ -571,7 +571,7 @@ public class LocaleNames_lv extends OpenListResourceBundle {
             { "WF", "Volisa un Futunas salas" },
             { "type.co.traditional", "tradicion\u0101l\u0101 k\u0101rto\u0161anas sec\u012bba" },
             { "057", "Mikron\u0113zijas re\u0123ions" },
-            { "jgo", "jgo" },
+            { "jgo", "ngomba" },
             { "lkt", "lakotu" },
             { "type.nu.finance", "Finan\u0161u cipari" },
             { "type.co.compat", "sader\u012bg\u0101 k\u0101rto\u0161anas sec\u012bba" },
@@ -581,7 +581,7 @@ public class LocaleNames_lv extends OpenListResourceBundle {
             { "was", "va\u0161o" },
             { "XA", "pseidoakcenti" },
             { "war", "varaju" },
-            { "XB", "pseido-Bidi" },
+            { "XB", "pseidodivvirzienu" },
             { "awa", "avadhu" },
             { "061", "Polin\u0113zija" },
             { "XK", "Kosova" },
@@ -596,7 +596,7 @@ public class LocaleNames_lv extends OpenListResourceBundle {
             { "YT", "Majota" },
             { "ZA", "Dienvid\u0101frikas Republika" },
             { "type.lb.loose", "Br\u012bvais rindi\u0146as p\u0101rtraukuma stils" },
-            { "Deva", "dev\u0101nag\u0101ri" },
+            { "Deva", "d\u0113van\u0101gari" },
             { "type.nu.geor", "Gruz\u012bnu cipari" },
             { "Hira", "hiragana" },
             { "ZM", "Zambija" },
@@ -914,7 +914,7 @@ public class LocaleNames_lv extends OpenListResourceBundle {
             { "bra", "brad\u017eie\u0161u" },
             { "key.ca", "Kalend\u0101rs" },
             { "Laoo", metaValue_lo },
-            { "mgo", "mgo" },
+            { "mgo", "metu" },
             { "type.hc.h23", "24 stundu sist\u0113ma (0\u201323)" },
             { "type.hc.h24", "24 stundu sist\u0113ma (1\u201324)" },
             { "ssy", metaValue_ssy },
@@ -928,7 +928,7 @@ public class LocaleNames_lv extends OpenListResourceBundle {
             { "type.hc.h11", "12 stundu sist\u0113ma (0\u201311)" },
             { "rm", "retorom\u0101\u0146u" },
             { "rn", "rundu" },
-            { "key.cu", "Val\u016bta" },
+            { "key.cu", "val\u016bta" },
             { "ro", "rum\u0101\u0146u" },
             { "%%SAAHO", metaValue_ssy },
             { "type.nu.orya", "Oriju cipari" },
@@ -1103,6 +1103,7 @@ public class LocaleNames_lv extends OpenListResourceBundle {
             { "type.nu.tamldec", "Tamilu cipari" },
             { "krc", "kara\u010daju un balk\u0101ru" },
             { "inh", "ingu\u0161u" },
+            { "fa_AF", "dar\u012b" },
             { "krl", "kar\u0113\u013cu" },
             { "efi", "efiku" },
             { "key.nu", "Cipari" },
