@@ -322,7 +322,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "SV", "Salvador" },
             { "SX", "Sint Maarten" },
             { "SY", "Sirija" },
-            { "SZ", "Svazi" },
+            { "SZ", "Esvatini" },
             { "TA", "Tristan da Cunha" },
             { "TC", "Otoki Turks in Caicos" },
             { "TD", "\u010cad" },
@@ -867,7 +867,6 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "Bugi", "buginski" },
             { "Buhd", "buhidski" },
             { "Cans", "poenotena zlogovna pisava kanadskih staroselcev" },
-            { "Cham", "Cham" },
             { "Cher", "\u010deroke\u0161ki" },
             { "Cirt", "kirt" },
             { "Copt", "koptski" },
@@ -985,6 +984,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "en_US", "angle\u0161\u010dina (ZDA)" },
             { "es_ES", "evropska \u0161pan\u0161\u010dina" },
             { "es_MX", "mehi\u0161ka \u0161pan\u0161\u010dina" },
+            { "fa_AF", "darij\u0161\u010dina" },
             { "fr_CA", "kanadska franco\u0161\u010dina" },
             { "fr_CH", "\u0161vicarska franco\u0161\u010dina" },
             { "nl_BE", "flam\u0161\u010dina" },
