@@ -100,6 +100,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "151", "\u02bbEulope fakahahake" },
             { "154", "\u02bbEulope fakatokelau" },
             { "155", "\u02bbEulope fakahihifo" },
+            { "202", "\u02bbAfilika fakasahala-tonga" },
             { "419", "\u02bbAmelika fakalatina" },
             { "AC", "Motu \u02bbAsenisini" },
             { "AD", "\u02bbAnitola" },
@@ -251,7 +252,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "MF", "S\u0101 M\u0101tini (fakafalanis\u0113)" },
             { "MG", "Matakasika" },
             { "MH", "\u02bbOtumotu M\u0101solo" },
-            { "MK", "Maset\u014dnia" },
+            { "MK", "Maset\u014dnia fakatokelau" },
             { "ML", "M\u0101li" },
             { "MM", "Mianim\u0101 (Pema)" },
             { "MN", "Mongok\u014dlia" },
@@ -321,7 +322,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "SV", "\u02bbEle Salavatoa" },
             { "SX", "S\u0101 M\u0101tini (fakah\u014dlani)" },
             { "SY", "S\u012blia" },
-            { "SZ", "Suasilani" },
+            { "SZ", "\u02bbEsuatini" },
             { "TA", "Tulisitani ta Kunuha" },
             { "TC", "\u02bbOtumotu Tuki mo Kaikosi" },
             { "TD", "S\u0101ti" },
@@ -330,7 +331,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "TH", "Tailani" },
             { "TJ", "Tasikitani" },
             { "TK", "Tokelau" },
-            { "TL", "Timoa hahake" },
+            { "TL", "Timoa fakahahake" },
             { "TM", "T\u016bkimenisitani" },
             { "TN", "Tun\u012bsia" },
             { "TO", "Tonga" },
@@ -355,6 +356,8 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "VU", "Vanuatu" },
             { "WF", "\u02bbUvea mo Futuna" },
             { "WS", "Ha\u02bbamoa" },
+            { "XA", "fasi\u02bbalea loi" },
+            { "XB", "fua-ua loi" },
             { "XK", "K\u014dsovo" },
             { "YE", "Iemeni" },
             { "YT", "Maiote" },
@@ -609,6 +612,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "car", "lea fakakalipa" },
             { "cay", "lea fakakaiuka" },
             { "cch", "lea faka\u02bbatisami" },
+            { "ccp", "lea fakas\u0101kima" },
             { "ceb", "lea fakasepuano" },
             { "cgg", "lea fakakika" },
             { "chb", "lea fakas\u012bpisa" },
